#!/bin/sh
TMPFILE=/tmp/check.$$
QUIET=false
if [ -x ../../maude.linux ] ; then   
   MAUDE=../../maude.linux
else
   MAUDE=maude
fi
TOTALFAILED=0
checkOne(){
   if [ "${QUIET}" = "false" ] ; then
      ${MAUDE} -no-wrap < ${i} 2>${TMPFILE} | awk -f checkSolution.awk
   else     
     FAILED=`${MAUDE} -no-wrap < ${i} 2>${TMPFILE} | grep -c "No solution."`
     if [ $FAILED -gt 0 ] ; then 
        echo "      failed: "$FAILED
        TOTALFAILED=$(( ${TOTALFAILED} + ${FAILED} ))
     fi
   fi
  # Print error messages
  grep -v "^Advisory: <automatic>: operator " ${TMPFILE} | \
  grep -v "Warning: membership axioms are not guaranteed to" | \
  grep -v "Warning: sort declarations .* failed preregularity check " | \
  grep -v '^[ ]*\"prelude.maude\", line [0123456789]* (fmod LIST) and \"prelude.maude\", line [0123456789]* (fmod' | \
  grep -v "^Advisory: redefining module" | \
  grep -v "^Advisory: redefining view" | \
  grep -v "^Advisory: reexamining view" | \
  grep -v "^Advisory: reparsing module" | \
  grep -v "^Advisory: .* has been imported .* with no common ancestor." | \
  grep -v "^Warning: sort declarations for associative operator" | \
  grep -v "^[ ]*LIST) with no common ancestor."
  rm ${TMPFILE}
}
echo "Using "${MAUDE}" as maude tool"
# gestion des options
while getopts q OPT
do
   case $OPT in
   q) QUIET=true
      echo "Option quiet on"
   ;;
   esac
done
shift $((OPTIND - 1 ))

if [ $# -eq 0 ] ; then
    make
    ARG=test*.maude
else
    ARG=$*
fi
for i in $ARG ; do
  echo "Test: "$i
  checkOne ;
done        
if  [ "${QUIET}" = "true" ] ; then
  echo "Total test failed= "${TOTALFAILED}
fi
